summaryrefslogtreecommitdiffstats
path: root/modules/mono
diff options
context:
space:
mode:
authorRémi Verschelde <rverschelde@gmail.com>2024-09-12 09:25:27 +0200
committerRémi Verschelde <rverschelde@gmail.com>2024-09-12 09:25:27 +0200
commitcee14dbff2073ae5e0047c1b68c78dcbe4bb0181 (patch)
treea1ec446aabf4a17a1b1be4bfeec765dc840aadb5 /modules/mono
parentea9ad8d6a1fdb7a9cf03854be5aa7f12620321ab (diff)
parenta29ddd46746d7dd95d764990ef06e9a1f148b7f7 (diff)
downloadredot-engine-cee14dbff2073ae5e0047c1b68c78dcbe4bb0181.tar.gz
Merge pull request #96301 from scgm0/Delete-old-C#-data
C#: Clear existing data directory extracted from PCK
Diffstat (limited to 'modules/mono')
-rw-r--r--modules/mono/godotsharp_dirs.cpp10
1 files changed, 8 insertions, 2 deletions
diff --git a/modules/mono/godotsharp_dirs.cpp b/modules/mono/godotsharp_dirs.cpp
index 3935854a29..039263b405 100644
--- a/modules/mono/godotsharp_dirs.cpp
+++ b/modules/mono/godotsharp_dirs.cpp
@@ -192,8 +192,14 @@ private:
}
}
if (!has_data) {
- // 3. Extract the data to a temporary location to load from there.
- Ref<DirAccess> da = DirAccess::create_for_path(packed_path);
+ // 3. Extract the data to a temporary location to load from there, delete old data if it exists but is not up-to-date.
+ Ref<DirAccess> da;
+ if (DirAccess::exists(data_dir_root)) {
+ da = DirAccess::open(data_dir_root);
+ ERR_FAIL_COND(da.is_null());
+ ERR_FAIL_COND(da->erase_contents_recursive() != OK);
+ }
+ da = DirAccess::create_for_path(packed_path);
ERR_FAIL_COND(da.is_null());
ERR_FAIL_COND(da->copy_dir(packed_path, data_dir_root) != OK);
}